## v1.1.0 (2025-12-22)

### Feat

- **docker**: update docker images, change default transport to http
- **sentry**: add optional Sentry integration for error tracking and performance monitoring
- **docker**: add Docker usage instructions for easy deployment
- add fastmcp.json configuration
- **sentry**: add optional Sentry integration for error tracking and performance monitoring
- add publish workflow to PyPI and update project metadata
- **deps**: add commitizen for conventional commits

### Fix

- update license classifier to AGPLv3+
- **server**: remove unnecessary dependencies from FastMCP initialization
- **workflows**: update actions/checkout and change MCPO docker image

## v1.0.0 (2025-08-29)
